@@ -1,20 +1,29 @@
 package Email::Abstract::MailInternet;
 use strict;
+sub target { "Mail::Internet" }
 
 sub construct {
     require Mail::Internet;
     my ($class, $rfc822) = @_;
-    Mail::Internet->new([ split /\n/, $rfc822]);
+    Mail::Internet->new([ map { "$_\n" } split /\n/, $rfc822]);
 }
 
 sub get_header { 
     my ($class, $obj, $header) = @_; 
-    $obj->head->get($header); 
+    my @values = $obj->head->get($header); 
+
+    # No reason to s/// lots of values if we're just going to return one.
+    $#values = 0 if not wantarray;
+
+    chomp @values;
+    s/(?:\x0d\x0a|\x0a\x0d|\x0a|\x0d)\s+/ /g for @values;
+
+    return wantarray ? @values : $values[0];
 }
 
-sub get_body   { 
+sub get_body { 
     my ($class, $obj) = @_; 
-    join "\n", @{$obj->body()};
+    join "", @{$obj->body()};
 }
 
 sub set_header { 
@@ -23,9 +32,9 @@ sub set_header {
     $obj->head->replace($header, shift @data, ++$count) while @data; 
 }
 
-sub set_body   {
+sub set_body {
     my ($class, $obj, $body) = @_; 
-    $obj->body( split /\n/, $body ); 
+    $obj->body( map { "$_\n" } split /\n/, $body ); 
 }
 
 sub as_string { my ($class, $obj) = @_; $obj->as_string(); }
